@@ -1,6 +1,5 @@
 # -*- coding=utf-8 -*-
 """Preprocessing functions for ssd-mobilenet."""
-from typing import Tuple
 import numpy as np
 import cv2
 from PIL import Image
@@ -17,21 +16,11 @@ def image_to_tensor(image: Image) -> np.ndarray:
 
     Returns
     -------
-    tensor
-        Preprocessed numpy array.
+    np.ndarray tensor used by the network
     """
     image = image.convert('RGB')
-    tensor = np.asarray(image, dtype=np.float32)
+    tensor = np.asarray(image)
     tensor = cv2.resize(tensor, (300, 300))
+    tensor = (tensor / 255.0 - 0.5) * 2.0
     assert tensor.shape == (300, 300, 3)
     return tensor
-
-
-def preprocess_tensor(preprocess_runner, image: Image) -> Tuple[np.ndarray, np.ndarray]:
-    """Preprocess image for the network."""
-    image = image.convert('RGB')
-    tensor = np.asarray(image)
-
-    tensor = np.expand_dims(tensor, axis=0)
-    prepr_tensor = preprocess_runner(tensor)
-    return prepr_tensor, tensor
