@@ -99,7 +99,58 @@ def draw_boxes(
     return img
 
 
-def yolo_layer(inputs, n_classes, anchors, img_size):
+def filter_detections(detections: Dict[int, np.ndarray]) -> np.ndarray:
+    """
+    Pop empty classes and convert to Ground Truth format.
+
+    Parameters
+    ----------
+    detections
+        Postprocessing tensors result
+
+    Returns
+    -------
+    Postprocessed tensors result without empty classes
+    """
+    labels = []
+    labels_which_detect = [None if detections[key].size == 0 else key for key in list(detections.keys())]
+    for value in labels_which_detect:
+        if value is not None:
+            number_of_cl_detect = np.shape(detections[value][:, :5])[0]
+            for num in range(number_of_cl_detect):
+                labels.append((value, *detections[value][num, :5]))
+    detections_as_array = np.asarray(labels)
+    return detections_as_array
+
+
+def rescale_post(postprocessed: np.ndarray, size: tuple, yolo_size: int) -> np.ndarray:
+    """
+    Rescale image according to the image size.
+
+    Parameters
+    ----------
+    postprocessed
+        initial postprocessed data
+    size
+        size of the image
+    yolo_size
+        size of the network (YOLO3) input
+
+    Returns
+    -------
+    ndarray of resized boxes
+    """
+    for key in range(np.shape(postprocessed)[0]):
+        class_, xmin, ymin, xmax, ymax, confidence = postprocessed[key]
+        ymin = ymin * size[1] / yolo_size
+        xmin = xmin * size[0] / yolo_size
+        ymax = ymax * size[1] / yolo_size
+        xmax = xmax * size[0] / yolo_size
+        postprocessed[key] = class_, xmin, ymin, xmax, ymax, confidence
+    return postprocessed
+
+
+def yolo_layer(inputs, input_name, n_classes, anchors, img_size):
     """
     Create Yolo final detection layer. Detect boxes with respect to anchors.
 
@@ -107,6 +158,8 @@ def yolo_layer(inputs, n_classes, anchors, img_size):
     ----------
     inputs
         Tensor input.
+    input_name
+        Name of the tensor input
     n_classes
         Number of labels.
     anchors
@@ -119,7 +172,9 @@ def yolo_layer(inputs, n_classes, anchors, img_size):
          Tensor output.
     """
     n_anchors = len(anchors)
-    inputs = tf.placeholder(shape=inputs.shape, dtype='float32', name='detection_placeholder')
+    if input_name[-2:] == ':0':
+        input_name = input_name[:-2]
+    inputs = tf.placeholder(shape=inputs.shape, dtype='float32', name=input_name)
     shape = inputs.get_shape().as_list()
     grid_shape = shape[1:3]
     inputs = tf.reshape(inputs, [-1, n_anchors * grid_shape[0] * grid_shape[1],
@@ -234,31 +289,37 @@ def build_detection_graph(
     keys = list(output_tensors.keys())
     if len(keys) == 2:
         detect0 = yolo_layer(output_tensors[keys[0]],
+                             input_name=keys[0],
                              n_classes=n_classes,
                              anchors=anchors[3:6],
                              img_size=input_shape)
         detect1 = yolo_layer(output_tensors[keys[1]],
+                             input_name=keys[1],
                              n_classes=n_classes,
                              anchors=anchors[0:3],
                              img_size=input_shape)
         output_tensors = tf.concat([detect0, detect1], axis=1)
     else:
         detect0 = yolo_layer(output_tensors[keys[0]],
+                             input_name=keys[0],
                              n_classes=n_classes,
                              anchors=anchors[6:9],
                              img_size=input_shape)
         detect1 = yolo_layer(output_tensors[keys[1]],
+                             input_name=keys[1],
                              n_classes=n_classes,
                              anchors=anchors[3:6],
                              img_size=input_shape)
         detect2 = yolo_layer(output_tensors[keys[2]],
+                             input_name=keys[2],
                              n_classes=n_classes,
                              anchors=anchors[0:3],
                              img_size=input_shape)
         output_tensors = tf.concat([detect0, detect1, detect2], axis=1)
     raw_boxes = build_boxes(output_tensors)
     boxes_dicts = non_max_suppression(
-        raw_boxes, n_classes=n_classes,
+        raw_boxes,
+        n_classes=n_classes,
         max_output_size=MAX_OUT_SIZE,
         iou_threshold=iou_threshold,
         confidence_threshold=confidence_threshold)
